Package: MexicoDataAPI
Type: Package
Title: Access Mexican Data via APIs and Curated Datasets
Version: 0.2.0
Maintainer: Renzo Caceres Rossi <arenzocaceresrossi@gmail.com>
Description: Provides functions to access data from public RESTful APIs including
    'REST Countries API', 'World Bank API', and 'Nager.Date API', covering Mexico's economic
    indicators, population statistics, literacy rates, international geopolitical
    information and official public holidays. The package also includes curated
    datasets related to Mexico such as air quality monitoring stations, pollution
    zones, income surveys, postal abbreviations, election studies, forest
    productivity and demographic data by state. It supports research and analysis
    focused on Mexico by integrating reliable global APIs with structured national
    datasets drawn from open and academic sources. 
    For more information on the APIs, see: 
        'REST Countries API' <https://restcountries.com/>, 
        'World Bank API' <https://datahelpdesk.worldbank.org/knowledgebase/articles/889392>, 
        and 'Nager.Date API' <https://date.nager.at/Api>.
License: GPL-3
URL: https://github.com/lightbluetitan/mexicodataapi,
        https://lightbluetitan.github.io/mexicodataapi/
BugReports: https://github.com/lightbluetitan/mexicodataapi/issues
Encoding: UTF-8
Depends: R (>= 4.1.0)
Imports: utils, httr, jsonlite, dplyr, scales, tibble
Suggests: ggplot2, testthat (>= 3.0.0), knitr, rmarkdown
Authors@R: 
    person(
        given = "Renzo",
        family = "Caceres Rossi",
        role = c("aut", "cre"),
        email = "arenzocaceresrossi@gmail.com",
        comment = c(ORCID = "0009-0005-0744-854X")
    )
RoxygenNote: 7.3.2
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-09-12 23:19:44 UTC; Renzo
Author: Renzo Caceres Rossi [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-0744-854X>)
Repository: CRAN
Date/Publication: 2025-09-13 22:40:08 UTC
Built: R 4.6.0; ; 2026-04-29 04:53:20 UTC; unix
