# Generated by roxygen2: do not edit by hand

export(chiapas_dry_forests_df)
export(get_mexico_cpi)
export(get_mexico_gdp)
export(get_mexico_holidays)
export(get_mexico_life_expectancy)
export(get_mexico_literacy_rate)
export(get_mexico_population)
export(get_mexico_unemployment)
export(mex_income_2008_tbl_df)
export(mex_income_2016_tbl_df)
export(mexico_abb_chr)
export(mexico_elections_df)
export(mexico_states_df)
export(pollution_stations_df)
export(pollution_zones_df)
export(stations_sinaica_df)
export(view_datasets_MexicoDataAPI)
importFrom(dplyr,as_tibble)
importFrom(dplyr,mutate)
importFrom(dplyr,tibble)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(httr,status_code)
importFrom(jsonlite,fromJSON)
importFrom(scales,comma)
importFrom(tibble,tibble)
