# MexicoDataAPI - Access Mexican Data via APIs and Curated Datasets
# Version 0.3.0
# Copyright (C) 2025-2026 Renzo Caceres Rossi
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

#' MexicoDataAPI: Access Mexican Data via APIs and Curated Datasets
#'
#' \if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}
#'
#' Access Mexican Data via APIs and Curated Datasets.
#'
#' @name MexicoDataAPI
#' @aliases MexicoDataAPI-package
#' @title MexicoDataAPI: Access Mexican Data via APIs and Curated Datasets
#' @description {
#' This package provides functions to access data from the 'World Bank API','REST Countries API' and 'Nager.Date API', covering Mexico's economic indicators, population statistics, literacy rates, international geopolitical information and official public holidays. The package also includes curated datasets related to Mexico such as air quality monitoring stations, pollution zones, income surveys, postal abbreviations, election studies and more.
#' }
#' @seealso {
#' Useful links:
#' \itemize{
#'   \item \url{https://github.com/lightbluetitan/mexicodataapi}
#' }
#' }
#' @author {
#' \strong{Maintainer}: Renzo Caceres Rossi \email{arenzocaceresrossi@gmail.com}
#' }
'_PACKAGE'
